/****************************************************************************
    Qt-BSch3V schematic capture
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include "editcomment.h"

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <q3whatsthis.h>
//Added by qt3to4:
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QEvent>

/* 
 *  Constructs a editcommentBase which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
editcommentBase::editcommentBase( QWidget* parent,  const char* name, bool modal, Qt::WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "editcommentBase" );
    resize( 378, 86 ); 
    setProperty( "caption", tr( "Qt-BSch EditComment" ) );
    setProperty( "sizeGripEnabled", QVariant( FALSE, 0 ) );
    editcommentBaseLayout = new QVBoxLayout( this ); 
    editcommentBaseLayout->setSpacing( 6 );
    editcommentBaseLayout->setMargin( 11 );

    LineEdit = new QLineEdit( this, "LineEdit" );
    QFont LineEdit_font(  LineEdit->font() );
    LineEdit_font.setPointSize( 12 );
    LineEdit->setFont( LineEdit_font ); 
    editcommentBaseLayout->addWidget( LineEdit );

    Layout4 = new QHBoxLayout; 
    Layout4->setSpacing( 6 );
    Layout4->setMargin( 0 );

    FontButton = new QPushButton( this, "FontButton" );
    FontButton->setProperty( "text", tr( "Font..." ) );
    Layout4->addWidget( FontButton );
    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    Layout4->addItem( spacer );

    buttonOk = new QPushButton( this, "buttonOk" );
    buttonOk->setProperty( "caption", tr( "" ) );
    buttonOk->setProperty( "text", tr( "&OK" ) );
    buttonOk->setProperty( "autoDefault", QVariant( TRUE, 0 ) );
    buttonOk->setProperty( "default", QVariant( TRUE, 0 ) );
    Layout4->addWidget( buttonOk );

    buttonCancel = new QPushButton( this, "buttonCancel" );
    buttonCancel->setProperty( "text", tr( "&Cancel" ) );
    buttonCancel->setProperty( "autoDefault", QVariant( TRUE, 0 ) );
    Layout4->addWidget( buttonCancel );
    editcommentBaseLayout->addLayout( Layout4 );

    // signals and slots connections
    connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
    connect( FontButton, SIGNAL( clicked() ), this, SLOT( fontbuttonClicked() ) );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
editcommentBase::~editcommentBase()
{
    // no need to delete child widgets, Qt does it all for us
}

/*  
 *  Main event handler. Reimplemented to handle application
 *  font changes
 */
bool editcommentBase::event( QEvent* ev )
{
    bool ret = QDialog::event( ev ); 
    if ( ev->type() == QEvent::ApplicationFontChange ) {
	QFont LineEdit_font(  LineEdit->font() );
	LineEdit_font.setPointSize( 12 );
	LineEdit->setFont( LineEdit_font ); 
    }
    return ret;
}

void editcommentBase::fontbuttonClicked()
{
    qWarning( "editcommentBase::fontbuttonClicked(): Not implemented yet!" );
}

